@@ -21,16 +21,6 @@
 """
 a (very basic) script to markovify a text file and
 output a user-specified number of sentences to a text file. see --help for other options.
-
-TODO: implement newline texts rather than full stop texts. (good for poetry no?)
-
-it is a separate class/function in markovify, like so:
-
-class NewlineText(Text):
-     # A (usable) example of subclassing markovify.Text. This one lets you markovify text where the sentences are separated by newlines instead of ". "
-    def sentence_split(self, text):
-        return re.split(r"\s*\n\s*", text)
-
 """
    
      
@@ -47,34 +37,45 @@ def main():
     parser.add_argument('outfile', nargs='?', default="./mkv-output.txt", help="the file to save to, with path. if the file is used more than once, subsequent literature will be appended to the file after a star. defaults to ./mkv-output.txt.")
 
     # optional args:
-    parser.add_argument('-s', '--statesize', help="the number of preceeding words used to calculate the probability of the next word. defaults to 2, 1 makes it more random, 3 less so. must be an integer. anything more than 4 will likely have little effect.", type=int, default=2)
+    parser.add_argument('-s', '--state-size', help="the number of preceeding words used to calculate the probability of the next word. defaults to 2, 1 makes it more random, 3 less so. must be an integer. anything more than 4 will likely have little effect.", type=int, default=2)
     # if i use --state-size (w a dash), type=int doesn't work.
     parser.add_argument('-n', '--sentences', help="the number of 'sentences' to output. defaults to 5. must be an integer.", type=int, default=5)
     parser.add_argument('-l', '--length', help="set maximum number of characters per sentence. must be an integer.", type=int)
     parser.add_argument('-o', '--overlap', help="the amount of overlap allowed between original text and the output, expressed as a ratio between 0 and 1. defaults to 0.5", type=float, default=0.5)
-    parser.add_argument('--newline', help="sentences in input file end with newlines rather than with full stops.", action='store_true') # store_true means default to False, and becomes True if flagged.
+    parser.add_argument('-f', '--no-well-formed', help="don't enforce 'well_formed', ie allow the inclusion of sentences with []{}()""'' in them in the markov model. this might filth up your text, especially if it contains 'smart' quotes.", action='store_false') # store_false = default to True.
+    parser.add_argument('--newline', help="sentences in input file end with newlines rather than with full stops.", action='store_true')
+    # store_true = default to False, become True if flagged.
     parser.add_argument('-c', '--combine', help="provide an another input text file with path to be combined with the first.")
     parser.add_argument('-w', '--weight', help="specify the weight to be given to the second text provided with --combine. defaults to 1, and the weight of the initial text is also 1. setting this to 1.5 will place 50 percent more weight on the second text, while setting it to 0.5 will place less.", type=float, default=1)
 
     args = parser.parse_args()
 
+    fnf = 'error: file not found. please provide a path to a really-existing file!'
+    
     # if a combine file is provided, combine it w/ input file:
     if args.combine :
         # get raw text as a string for both files:
-        with open(args.infile, encoding="latin-1") as f:
-            text = f.read()
-
-        with open(args.combine, encoding="latin-1") as cf:
-            ctext = cf.read()
+        try:
+            with open(args.infile, encoding="latin-1") as f:
+                text = f.read()
+            with open(args.combine, encoding="latin-1") as cf:
+                ctext = cf.read()
+        except FileNotFoundError:
+            print(fnf)
+            sys.exit()
 
         # build the models and build a combined model:
         # NB: attempting to implement Newline option here (and below):
         if args.newline :
-            text_model = markovify.NewlineText(text, state_size=args.statesize)
-            ctext_model = markovify.NewlineText(ctext, state_size=args.statesize)
+            text_model = markovify.NewlineText(
+                text, state_size=args.state_size, well_formed=args.no_well_formed)
+            ctext_model = markovify.NewlineText(
+                ctext, state_size=args.state_size, well_formed=args.no_well_formed)
         else:
-            text_model = markovify.Text(text, state_size=args.statesize)
-            ctext_model = markovify.Text(ctext, state_size=args.statesize)
+            text_model = markovify.Text(text,
+                state_size=args.state_size, well_formed=args.no_well_formed)
+            ctext_model = markovify.Text(ctext,
+                state_size=args.state_size, well_formed=args.no_well_formed)
 
         combo_model = markovify.combine([text_model, ctext_model], [1, args.weight])
 
@@ -95,17 +96,23 @@ def main():
         # if no combo file, just do normal:
     else:
         # Get raw text as string.
-        with open(args.infile, encoding="latin-1") as f:
-            text = f.read()
+        try:
+            with open(args.infile, encoding="latin-1") as f:
+                text = f.read()
+        except FileNotFoundError:
+            print(fnf)
+            sys.exit()
         
         # Build the model:
         # NB: this errors if infile is EMPTY:
 
-        ## implement newline option here:
+        ## newline option:
         if args.newline :
-            text_model = markovify.NewlineText(text, state_size=args.statesize)
+            text_model = markovify.NewlineText(text,
+                state_size=args.state_size, well_formed=args.no_well_formed)
         else:
-            text_model = markovify.Text(text, state_size=args.statesize)
+            text_model = markovify.Text(text,
+                state_size=args.state_size, well_formed=args.no_well_formed)
 
         # Print -n number of randomly-generated sentences
         for i in range(args.sentences):
