@@ -39,10 +39,11 @@ def main():
     parser.add_argument('outfile', nargs='?', default="./mkv-dir-output.txt", help="the file to save to, with path. if the file is used more than once, subsequent literature will be appended to the file after a star. defaults to ./mkv-dir-output.txt.")
 
     # optional args:
-    parser.add_argument('-s', '--statesize', help="the number of preceeding words the probability of the next word depends on. defaults to 2, 1 makes it more random, 3 less so.", type=int, default=2)
+    parser.add_argument('-s', '--state-size', help="the number of preceeding words the probability of the next word depends on. defaults to 2, 1 makes it more random, 3 less so.", type=int, default=2)
     parser.add_argument('-n', '--sentences', help="the number of 'sentences' to output. defaults to 5.", type=int, default=5)
     parser.add_argument('-l', '--length', help="set maximum number of characters per sentence.", type=int)
     parser.add_argument('-o', '--overlap', help="the amount of overlap allowed between original text and the output, expressed as a radio between 0 and 1. lower values make it more random. defaults to 0.5", type=float, default=0.5)
+    parser.add_argument('-f', '--no-well-formed', help="don't enforce 'well_formed', ie allow the inclusion of sentences with []{}()""'' in them in the markov model. this might filth up your text, especially if it contains 'smart' quotes.", action='store_false') # store_false = default to True.
     parser.add_argument('--newline', help="sentences in input file end with newlines rather than with full stops.", action='store_true')
     parser.add_argument('-c', '--combine', help="provide an another input text file with path to be combined with the first.")
     parser.add_argument('-w', '--weight', help="specify the weight to be given to the second text provided with --combine. defaults to 1, and the weight of the initial text is also 1. setting this to 1.5 will place 50 percent more weight on the second text. setting it to 0.5 will place less.", type=float, default=1)
@@ -51,11 +52,15 @@ def main():
 
     #create a list of files to concatenate:
     matches = []
-    for root, dirnames, filenames in os.walk(args.indir):
-        for filename in filenames:
-            if filename.endswith(('.txt', '.org', '.md')):
-                matches.append(os.path.join(root, filename))
-
+    if os.path.isdir(args.indir) is True:
+        for root, dirnames, filenames in os.walk(args.indir):
+            for filename in filenames:
+                if filename.endswith(('.txt', '.org', '.md')):
+                    matches.append(os.path.join(root, filename))
+    else:
+        print('error: please enter a valid directory')
+        sys.exit()
+        
     # place batchfile.txt in user-given directory:
     batchfile = os.path.dirname(args.indir) + os.path.sep + 'batchfile.txt'
 
@@ -73,9 +78,11 @@ def main():
     
     # Build the model:
     if args.newline :
-        text_model = markovify.NewlineText(text, state_size=args.statesize)
+        text_model = markovify.NewlineText(text,
+            state_size=args.state_size, well_formed=args.no_well_formed)
     else:
-        text_model = markovify.Text(text, state_size=args.statesize)
+        text_model = markovify.Text(text,
+            state_size=args.state_size, well_formed=args.no_well_formed)
 
     # Print -n number of randomly-generated sentences
     for i in range(args.sentences):
